.. expect: Line ends with dangling hyphen (dangling-hyphen)

Additionally, this PEP requires that the default class definition
namespace be ordered (e.g. ``OrderedDict``) by default.  The long-
lived class namespace (``__dict__``) will remain a ``dict``.
